@@ -1,12 +1,13 @@
 import unittest
 import pysal.examples as ex
+import os
 
 
 class Example_Tester(unittest.TestCase):
     def test_get_path(self):
-        pathparts = ex.get_path('').split('/')
-        self.localpath = '/'.join(pathparts[-3:])
-        self.assertEqual(self.localpath, 'pysal/examples/')
+        pathparts = os.path.normpath(ex.get_path('')).split(os.path.sep)
+        self.localpath = os.path.join(*pathparts[-2:])
+        self.assertEqual(self.localpath, os.path.normpath('pysal/examples/'))
 
     def test_parser(self):
         for example in ex.available():
