@@ -331,19 +331,24 @@ class Network:
 
         return ps.weights.W(neighbors, weights=weights)
 
-    def distancebandweights(self, threshold):
+    def distancebandweights(self, threshold, n_proccess=None):
         """
         Create distance based weights
 
         Parameters
         ----------
-        threshold:  float
-                    Distance threshold value.
+        threshold:      float
+                        Distance threshold value.
+        
+        n_processes:    int, str
+                        (Optional) Specify the number of cores to utilize.
+                        Default is 1 core. Use (int) to specify an exact number or cores.
+                        Use ("all") to request all available cores.
         """
         try:
             hasattr(self.alldistances)
         except:
-            self.node_distance_matrix()
+            self.node_distance_matrix(n_proccess)
 
         neighbor_query = np.where(self.distancematrix < threshold)
         neighbors = defaultdict(list)
@@ -627,19 +632,46 @@ class Network:
             links.append(tuple(sorted([n, v0])))
         return links
 
-    def node_distance_matrix(self):
+    def node_distance_matrix(self, n_processes):
+        """
+        Called from: allneighbordistances()
+                     nearestneighbordistances()
+                     distancebandweights()
+        """
         self.alldistances = {}
         nnodes = len(self.node_list)
         self.distancematrix = np.empty((nnodes, nnodes))
-        for node in self.node_list:
-            distance, pred = util.dijkstra(self, self.edge_lengths, node, n=float('inf'))
+        # Single-core processing
+        if not n_processes:
+            for node in self.node_list:
+                distance, pred = util.dijkstra(self, self.edge_lengths, node, n=float('inf'))
+                pred = np.array(pred)
+                #tree = util.generatetree(pred)     <---- something to look at in the future
+                tree = None
+                self.alldistances[node] = (distance, tree)
+                self.distancematrix[node] = distance
+        # Multiprocessing
+        if n_processes:
+            import multiprocessing as mp
+            from itertools import repeat
+            if n_processes == "all":
+                cores = mp.cpu_count()
+            else:
+                cores = n_processes
+            p = mp.Pool(processes=cores)
+            distance_pred = p.map(util.dijkstra_multi, list(zip(repeat(self), 
+                                                       repeat(self.edge_time), 
+                                                       self.node_list)))
+            distance = [distance_pred[iteration][0] for iteration in range(len(distance_pred))]
+            pred = [distance_pred[iteration][1] for iteration in range(len(distance_pred))]
             pred = np.array(pred)
-            #tree = util.generatetree(pred)     <---- something to look at in the future
-            tree = None
-            self.alldistances[node] = (distance, tree)
-            self.distancematrix[node] = distance
-
-    def allneighbordistances(self, sourcepattern, destpattern=None, fill_diagonal=None):
+            #tree = util.generatetree(pred[node])
+            for node in self.node_list:
+                self.distancematrix[node] = distance[node]
+    
+    
+    def allneighbordistances(self, sourcepattern, destpattern=None, fill_diagonal=None,
+                             n_processes=None):
         """
         Compute either all distances between i and j in a single point pattern or all 
         distances between each i from a source pattern and all j from a destination pattern.
@@ -657,6 +689,10 @@ class Network:
                         Default in None and will populate the diagonal with numpy.nan
                         Do not declare a destpattern for a custom fill_diagonal.
         
+        n_processes:    int, str
+                        (Optional) Specify the number of cores to utilize.
+                        Default is 1 core. Use (int) to specify an exact number or cores.
+                        Use ("all") to request all available cores.
         Returns
         -------
         nearest:        array (n,n)
@@ -664,7 +700,7 @@ class Network:
         """
 
         if not hasattr(self,'alldistances'):
-            self.node_distance_matrix()
+            self.node_distance_matrix(n_processes)
             
         # Source setup
         src_indices = list(sourcepattern.points.keys())
@@ -709,9 +745,8 @@ class Network:
                 if set1 == set2: # same edge
                     x1,y1 = sourcepattern.snapped_coordinates[p1]
                     x2,y2 = destpattern.snapped_coordinates[p2]
-                    xd = x1-x2
-                    yd = y1-y2
-                    nearest[p1,p2] = np.sqrt(xd*xd + yd*yd)
+                    computed_length = util.compute_length((x1,y1),(x2,y2))
+                    nearest[p1,p2] = computed_length
 
                 else:
                     ddist1, ddist2 = list(dest_dist_to_node[p2].values())
@@ -757,7 +792,7 @@ class Network:
             
         return nearest
 
-    def nearestneighbordistances(self, sourcepattern, destpattern=None):
+    def nearestneighbordistances(self, sourcepattern, destpattern=None, n_processes=None):
         """
         Compute the interpattern nearest neighbor distances or the intrapattern
         nearest neighbor distances between a source pattern and a destination pattern.
@@ -770,6 +805,11 @@ class Network:
         destpattern:    str 
                         (Optional) The key of a point pattern snapped to the network.
 
+        n_processes:    int, str
+                        (Optional) Specify the number of cores to utilize.
+                        Default is 1 core. Use (int) to specify an exact number or cores.
+                        Use ("all") to request all available cores.
+                        
         Returns
         -------
         nearest:        ndarray (n,2) 
@@ -781,7 +821,7 @@ class Network:
             raise KeyError("Available point patterns are {}".format(list(self.pointpatterns.keys())))
 
         if not hasattr(self,'alldistances'):
-            self.node_distance_matrix()
+            self.node_distance_matrix(n_processes)
 
         pt_indices = list(self.pointpatterns[sourcepattern].points.keys())
         dist_to_node = self.pointpatterns[sourcepattern].dist_to_node
